@@ -4,18 +4,18 @@
 #' @name scissors
 #' @title Remove the first n iterations.
 #' @description Removes iterations of the MCMC time series, and then updates the output file.
-#' @details Bacon will perform millions of MCMC iterations for each age-model run by default, although only a fraction 
-#' of these will be stored. In most cases the remaining MCMC iterations will be well mixed (the upper left panel 
+#' @details Bacon will perform millions of MCMC iterations for each age-model run by default, although only a fraction
+#' of these will be stored. In most cases the remaining MCMC iterations will be well mixed (the upper left panel
 #' of the fit of the iterations shows no undesirable features such as trends or sudden systematic drops or rises).
-#' If the run has a visible remaining burn-in, scissors can be used to remove them. 
+#' If the run has a visible remaining burn-in, scissors can be used to remove them.
 #' To remove, e.g., the first 300 iterations, type \code{scissors(300)}. To remove the last 300 iterations, type \code{scissors(-300)}. To remove iterations 300 to 600, type \code{scissors(300:600)}.
 #'
-#' @param burnin Number of iterations to remove  of the iterative time series. If this value is higher than the amount of remaining iterations, 
+#' @param burnin Number of iterations to remove  of the iterative time series. If this value is higher than the amount of remaining iterations,
 #' a warning is given and the iterations are not removed. If the provided number is negative, the iterations will be removed from the end of the run, not from the start. If a range is given, this range of iterations is removed.
 #' @param set Detailed information of the current run, stored within this session's memory as variable \code{info}.
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return NA
-#' @examples 
+#' @examples
 #' \dontshow{
 #'   Bacon(run=FALSE, coredir=tempfile())
 #'   scissors(100)
@@ -29,8 +29,8 @@
 #'
 #' @seealso \url{http://www.chrono.qub.ac.uk/blaauw/manualBacon_2.3.pdf}
 #' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive 
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
+#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
+#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
 #' \url{https://projecteuclid.org/euclid.ba/1339616472}
 #' @export
 scissors <- function(burnin, set=get('info')) {
@@ -38,7 +38,7 @@ scissors <- function(burnin, set=get('info')) {
   if(length(burnin) > 1) {
     if(length(burnin) >= nrow(output))
       stop("cannot remove that many iterations, there would be none left!", call.=FALSE)
-	output <- output[-burnin,] 
+	output <- output[-burnin,]
   } else {
       if(abs(burnin) >= nrow(output))
         stop("cannot remove that many iterations, there would be none left!", call.=FALSE)
@@ -46,9 +46,9 @@ scissors <- function(burnin, set=get('info')) {
 	    output <- output[-(1:burnin),] else
           output <- output[-((nrow(output)-abs(burnin)):nrow(output)),]
 	  }
-		  
+
   write.table(output, paste(set$prefix, ".out", sep=""), col.names=FALSE, row.names=FALSE)
-    
+
   info <- get('info')
   info$output <- output
   .assign_to_global ("info", info)
@@ -64,7 +64,7 @@ scissors <- function(burnin, set=get('info')) {
 #' @param set Detailed information of the current run, stored within this session's memory as variable \code{info}.
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return NA
-#' @examples 
+#' @examples
 #' \dontshow{
 #'   Bacon(run=FALSE, coredir=tempfile())
 #'   thinner(.1)
@@ -78,8 +78,8 @@ scissors <- function(burnin, set=get('info')) {
 #'
 #' @seealso \url{http://www.chrono.qub.ac.uk/blaauw/manualBacon_2.3.pdf}
 #' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive 
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
+#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
+#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
 #' \url{https://projecteuclid.org/euclid.ba/1339616472}
 #' @export
 thinner <- function(proportion=0.1, set=get('info')) {
@@ -89,7 +89,7 @@ thinner <- function(proportion=0.1, set=get('info')) {
   proportion <- sample(nrow(output), proportion*nrow(output))
   output <- output[-proportion,]
   write.table(output, paste(set$prefix, ".out", sep=""), col.names=FALSE, row.names=FALSE)
-    
+
   info <- get('info')
   info$output <- output
   .assign_to_global ("info", info)
@@ -97,20 +97,21 @@ thinner <- function(proportion=0.1, set=get('info')) {
 
 
 
-#' @name Baconvergence 
+#' @name Baconvergence
 #' @title Test to identify poorly mixed MCMC runs.
 #' @description Test how well-mixed and converged the MCMC runs are with the chosen core and settings, by running the core several times and comparing the different runs using the Gelman and Rubin Reduction factor (Brooks and Gelman, 1998).
-#' @details Generally Bacon will perform millions of MCMC iterations for each age-model run, although only a fraction 
-#' of these will be stored. In most cases the remaining MCMC iterations will be well mixed (the upper left panel 
+#' @details Generally Bacon will perform millions of MCMC iterations for each age-model run, although only a fraction
+#' of these will be stored. In most cases the remaining MCMC iterations will be well mixed (the upper left panel
 #' of the fit of the iterations shows no strange features such as sudden systematic drops or rises).
-#'  However if the iterations seem not well mixed, or if too few remain (say less than a few hundred), 
-#'  then you could check the Gelman and Rubin Reduction Factor. Too high differences (high Factors) between runs 
-#' indicate poor MCMC mixing. Robust MCMC mixing is indicated by a Gelman and Rubin Reduction factor 
+#'  However if the iterations seem not well mixed, or if too few remain (say less than a few hundred),
+#'  then you could check the Gelman and Rubin Reduction Factor. Too high differences (high Factors) between runs
+#' indicate poor MCMC mixing. Robust MCMC mixing is indicated by a Gelman and Rubin Reduction factor
 #' (Brooks and Gelman, 1998) below the 1.05 safety threshold.
-#' @param core Name of the core, given using quotes. Defaults to one of the cores provided with rbacon, \code{core="MSB2K"}. 
+#' @param core Name of the core, given using quotes. Defaults to one of the cores provided with rbacon, \code{core="MSB2K"}.
 #' @param runs Amount of runs to test for mixing. Default \code{runs=5}.
 #' @param suggest If initial analysis of the data indicates abnormally slow or fast accumulation rates, Bacon will suggest to change the prior.
-#' @param ... additional options that can be given to the Bacon function. 
+#' @param verbose Provide feedback on what is happening (default \code{verbose=TRUE}).
+#' @param ... additional options that can be given to the Bacon function.
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return NA
 #' @examples
@@ -119,25 +120,25 @@ thinner <- function(proportion=0.1, set=get('info')) {
 #'   }
 #' @seealso \url{http://www.chrono.qub.ac.uk/blaauw/manualBacon_2.3.pdf}
 #' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive 
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
+#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
+#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
 #' \url{https://projecteuclid.org/euclid.ba/1339616472}
 #' Brooks, SP. and Gelman, A. (1998) General methods for monitoring
-#' convergence of iterative simulations. 
+#' convergence of iterative simulations.
 #' _Journal of Computational and Graphical Statistics_, *7*, 434-455.
 #' @export
-Baconvergence <- function(core="MSB2K", runs=5, suggest=FALSE, ...) {
+Baconvergence <- function(core="MSB2K", runs=5, suggest=FALSE, verbose=TRUE, ...) {
   MCMC <- list()
   for(i in 1:runs) { # now the other runs
     cat("run number", i, "...\n")
     Bacon(core=core, suggest=suggest, run=TRUE, ask=FALSE, ...)
 	set <- get('info')
-    if(i == 1) 
-      nm <- set$prefix 
+    if(i == 1)
+      nm <- set$prefix
     MCMC[[i]] <- read.table(paste0(nm, ".out"))
     Bacon.cleanup()
   }
-  
+
   lmcmc <- c() # find the shortest run
   for(i in 1:runs)
     lmcmc <- min(lmcmc, nrow(MCMC[[i]]))
@@ -154,17 +155,19 @@ Baconvergence <- function(core="MSB2K", runs=5, suggest=FALSE, ...) {
     lines(MCMC[[i]][[dims]], col=i)
 
   rt <- gelman.diag(mcmc.list(lapply(MCMC, as.mcmc)), autoburnin=FALSE, transform=TRUE, confidence=0.97)
-  cat("Did", runs, "Bacon runs.\n")
-  cat("Gelman and Rubin Reduction Factor", rt$mpsrf, " (smaller and closer to 1 is better)\n")
-  if(rt$mpsrf > 1.05)
-    cat("Probably not a robust MCMC run! Too much difference between runs, above the 1.05 threshold. Increase sample size?\n", sep="") else
-      cat("Robust MCMC mixing, below the 1.05 safety threshold.\n", sep="")
+  if(verbose) {
+    message("Did", runs, "Bacon runs.")
+    message("Gelman and Rubin Reduction Factor", rt$mpsrf, " (smaller and closer to 1 is better).")
+    if(rt$mpsrf > 1.05)
+      message("Probably not a robust MCMC run! Too much difference between runs, above the 1.05 threshold. Increase sample size?\n") else
+        message("Robust MCMC mixing, below the 1.05 safety threshold.\n")
+  }
 }
 
 
 
 # calculate the proportion of dates that are within the age-depth model's confidence ranges
-overlap <- function(set=get('info'), digits=0) {
+overlap <- function(set=get('info'), digits=0, verbose=TRUE) {
   d <- set$dets[,4]
   inside <- rep(1, length(d))
   for(i in 1:length(d)) {
@@ -178,9 +181,9 @@ overlap <- function(set=get('info'), digits=0) {
         inside[i] <- 0
   }
   inside <- 100*sum(inside)/length(d)
-  if(inside < 80)
-    cat("Warning! Only ")
-  cat(round(inside, digits), "% of the dates overlap with the age-depth model (", 100*set$prob, "% ranges)\n", sep="")
+  if(verbose) {
+    if(inside < 80)
+      cat("Warning! Only ")
+    message(round(inside, digits), "% of the dates overlap with the age-depth model (", 100*set$prob, "% ranges)")
+  }
 }
-
-
